@@ -3,7 +3,7 @@
 
 
 # BleachBit
-# Copyright (C) 2008-2020 Andrew Ziem
+# Copyright (C) 2008-2021 Andrew Ziem
 # https://www.bleachbit.org
 #
 # This program is free software: you can redistribute it and/or modify
@@ -27,9 +27,8 @@ Preferences dialog
 from bleachbit import _, _p, online_update_notification_enabled
 from bleachbit.Options import options
 from bleachbit import GuiBasic
-import bleachbit.GUI
 
-from gi.repository import Gtk, Gdk
+from gi.repository import Gtk
 import logging
 import os
 
@@ -43,8 +42,6 @@ logger = logging.getLogger(__name__)
 LOCATIONS_WHITELIST = 1
 LOCATIONS_CUSTOM = 2
 
-win10_provider = None
-
 
 class PreferencesDialog:
 
@@ -87,8 +84,6 @@ class PreferencesDialog:
             self.cb_refresh_operations()
 
     def __toggle_callback(self, cell, path):
-        global win10_provider
-
         """Callback function to toggle option"""
         options.toggle(path)
         if online_update_notification_enabled:
@@ -99,12 +94,12 @@ class PreferencesDialog:
         if 'auto_hide' == path:
             self.refresh_operations = True
         if 'dark_mode' == path:
-            if os.name != 'nt' or options.get("win10_theme") == False:
-                Gtk.Settings.get_default().set_property(
-                    'gtk-application-prefer-dark-theme', options.get('dark_mode'))
+            if 'nt' == os.name and options.get('win10_theme'):
+                self.cb_set_windows10_theme()
+            Gtk.Settings.get_default().set_property(
+                'gtk-application-prefer-dark-theme', options.get('dark_mode'))
         if 'win10_theme' == path:
             self.cb_set_windows10_theme()
-            self.cb_dark_mode.set_sensitive(not options.get('win10_theme'))
         if 'debug' == path:
             from bleachbit.Log import set_root_log_level
             set_root_log_level()
@@ -200,10 +195,14 @@ class PreferencesDialog:
         self.cb_dark_mode = Gtk.CheckButton(label=_("Dark mode"))
         self.cb_dark_mode.set_active(options.get("dark_mode"))
         self.cb_dark_mode.connect('toggled', self.__toggle_callback, 'dark_mode')
-        if 'nt' == os.name:
-            self.cb_dark_mode.set_sensitive(not options.get('win10_theme'))
         vbox.pack_start(self.cb_dark_mode, False, True, 0)
 
+        # Remember window geometry (position and size)
+        self.cb_geom = Gtk.CheckButton(label=_("Remember window geometry"))
+        self.cb_geom.set_active(options.get("remember_geometry"))
+        self.cb_geom.connect('toggled', self.__toggle_callback, 'remember_geometry')
+        vbox.pack_start(self.cb_geom, False, True, 0)
+
         # Debug logging
         cb_debug = Gtk.CheckButton(label=_("Show debug messages"))
         cb_debug.set_active(options.get("debug"))
@@ -321,6 +320,7 @@ class PreferencesDialog:
 
         # finish
         swindow = Gtk.ScrolledWindow()
+        swindow.set_overlay_scrolling(False)
         swindow.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         swindow.set_size_request(300, 200)
         swindow.add(treeview)
@@ -463,6 +463,7 @@ class PreferencesDialog:
 
         # finish tree view
         swindow = Gtk.ScrolledWindow()
+        swindow.set_overlay_scrolling(False)
         swindow.set_policy(Gtk.PolicyType.AUTOMATIC, Gtk.PolicyType.AUTOMATIC)
         swindow.set_size_request(300, 200)
         swindow.add(treeview)
